@@ -8,7 +8,8 @@ import os
 import base64
 import warnings
 
-from influxdb_client import Configuration, ApiClient, HealthCheck, HealthService, Ready, ReadyService, PingService
+from influxdb_client import Configuration, ApiClient, HealthCheck, HealthService, Ready, ReadyService, PingService, \
+    InvocableScriptsApi
 from influxdb_client.client.authorizations_api import AuthorizationsApi
 from influxdb_client.client.bucket_api import BucketsApi
 from influxdb_client.client.delete_api import DeleteApi
@@ -37,9 +38,9 @@ class InfluxDBClient(object):
         :param timeout: HTTP client timeout setting for a request specified in milliseconds.
                         If one number provided, it will be total request timeout.
                         It can also be a pair (tuple) of (connection, read) timeouts.
-        :param enable_gzip: Enable Gzip compression for http requests. Currently only the "Write" and "Query" endpoints
+        :param enable_gzip: Enable Gzip compression for http requests. Currently, only the "Write" and "Query" endpoints
                             supports the Gzip compression.
-        :param org: organization name (used as a default in query and write API)
+        :param org: organization name (used as a default in Query, Write and Delete API)
         :key bool verify_ssl: Set this to false to skip verifying SSL certificate when calling API from https server.
         :key str ssl_ca_cert: Set this to customize the certificate file to verify the peer.
         :key str proxy: Set this to configure the http proxy to be used (ex. http://localhost:3128)
@@ -337,13 +338,21 @@ class InfluxDBClient(object):
 
     def query_api(self, query_options: QueryOptions = QueryOptions()) -> QueryApi:
         """
-        Create a Query API instance.
+        Create an Query API instance.
 
         :param query_options: optional query api configuration
         :return: Query api instance
         """
         return QueryApi(self, query_options)
 
+    def invocable_scripts_api(self) -> InvocableScriptsApi:
+        """
+        Create an InvocableScripts API instance.
+
+        :return: InvocableScripts API instance
+        """
+        return InvocableScriptsApi(self)
+
     def close(self):
         """Shutdown the client."""
         self.__del__()
